Stan Math Library: stan/math/prim/scal/fun/owens_t.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

owens_t.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_OWENS_T_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_OWENS_T_HPP
3
4 #include <boost/math/special_functions/owens_t.hpp>
5
6 namespace stan {
7 namespace math {
8
9
61 inline
62 double owens_t(const double h, const double a) {
63 return boost::math::owens_t(h, a);
64 }
65 }
66 }
67
68 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::owens_t
fvar< T > owens_t(const fvar< T > &x1, const fvar< T > &x2)
Definition: owens_t.hpp:14
stan::math::owens_t
var owens_t(double h, const var &a)
The Owen's T function of h and a.
Definition: owens_t.hpp:99

[ Stan Home Page ] © 2011–2016, Stan Development Team.